#
# spec file for package sysdig
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           sysdig
Version:        0.13.0
Release:        1.4
Summary:        System-level exploration
License:        GPL-2.0
Group:          System/Monitoring
Url:            http://www.sysdig.org/
Source0:        https://github.com/draios/%{name}/archive/%{version}/sysdig-%{version}.tar.gz
BuildRequires:  %{kernel_module_package_buildreqs}
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libb64-devel
BuildRequires:  libjq-devel
BuildRequires:  lua51-devel
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(jsoncpp)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(zlib)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%kernel_module_package
ExclusiveArch:  %{ix86} x86_64 s390 s390x

%description
Sysdig is open source, system-level exploration: capture system state and
activity from a running Linux instance, then save, filter and analyze.
Think of it as strace + tcpdump + lsof + awesome sauce. With a little Lua
cherry on top.

%prep
%setup -q

%build
export SYSDIG_CHISEL_DIR=%{_datadir}%{name}/chisels
%cmake \
  -DUSE_BUNDLED_JSONCPP=OFF \
  -DUSE_BUNDLED_LUAJIT=OFF \
  -DUSE_BUNDLED_ZLIB=OFF \
  -DUSE_BUNDLED_NCURSES=OFF \
  -DUSE_BUNDLED_OPENSSL=OFF \
  -DUSE_BUNDLED_CURL=OFF \
  -DUSE_BUNDLED_B64=OFF \
  -DUSE_BUNDLED_JQ=OFF \
  -DDIR_ETC=%{_sysconfdir} \
  -DBUILD_DRIVER=OFF \
  -Wno-dev
make %{?_smp_mflags}

%install
export INSTALL_MOD_PATH=%{buildroot}
%cmake_install
cd build
for flavor in %{flavors_to_build} ; do
	make KERNELDIR="%{_prefix}/src/linux-obj/%{_target_cpu}/$flavor" \
		clean install_driver DESTDIR=%{buildroot}
	make KERNELDIR="%{_prefix}/src/linux-obj/%{_target_cpu}/$flavor" \
		-C ../driver clean
done
rm -rf %{buildroot}%{_prefix}/src/*
%fdupes -s %{buildroot}/%{_datadir}

%files
%defattr(-,root,root,-)
%doc README.md COPYING
%config %{_sysconfdir}/bash_completion.d/sysdig
%{_bindir}/sysdig
%{_bindir}/csysdig
%{_bindir}/sysdig-probe-loader
%{_mandir}/man8/sysdig.8%{ext_man}
%{_mandir}/man8/csysdig.8%{ext_man}
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%dir %{_datadir}/zsh/vendor-completions
%{_datadir}/zsh/site-functions/_sysdig
%{_datadir}/zsh/vendor-completions/_sysdig
%{_datadir}/sysdig

%changelog
* Sat Dec 24 2016 mpluskal@suse.com
- Update to version 0.13.0 (boo#1017181):
  * Ability to open concatenated capture files
  * evtin.* fields can be used also for displaying now
  * Fix driver for Kernel 4.9
  * Fix on IPv4 mapped IPv6 parsing
  * Fix memory leak #694
  * Fix issue #687 about connecting to an K8s API server via HTTPS
* Tue Nov 15 2016 mpluskal@suse.com
- Update to version 0.12.1:
  * Compilation issues when using non-bundled OpenSSL #672
  * Compilation issues under S390 architecture
  * Various issues on k8s parsing
  * Stale thread info when parsing processes within containers #665
  * Avoid getting cwd from driver, causes issues on Kernel 4.8
- Changes for version 0.12.0:
  * New filters container.mount.* to match container mount points
  * New filter container.privileged to match containers running in
    privileged mode
  * Support latest kubernetes features: k8s.deployment.* and
    k8s.rs.* filters are now available
  * Added glob operator for strings, works as classic shell glob
    path matcher
  * Added pmatch operator
  * Add less package on docker image
- Drop upstreamed sysdig-do-not-use-private-jq-api.patch
- Enable building on s390x
* Sat Aug 20 2016 mpluskal@suse.com
- Use current macros for KMP building
  * drop sysdig-kmp-preamble
- Use exclusivearch instead of excluding architectures
* Fri Jul 15 2016 mpluskal@suse.com
- Update to version 0.11.0:
  * Support for tracers. A way to add user level events to sysdig
    stream. Seeannouncement blog post.
  * New csysdig views: Traces List, Traces Summary, Traces
    Spectogram
  * New evtin.* and span.* filters startswith operand for strings,
    ex: fd.name startswith /etc
  * evt.is_open_{read,write} fields, true or false if an event is
    an open() in read or write
  * Improved performances of Kubernetes metadata parsing.
  * Bug fixes for IPv6
- Add sysdig-do-not-use-private-jq-api.patch to allow building
  with system JQ
* Sun Jul  3 2016 mpluskal@suse.com
- Update to version 0.10.1:
  * Minor bugfixes, mostly related to Kubernetes and Mesos parsing
* Fri Jun 17 2016 mpluskal@suse.com
- Update to version 0.10.0:
  * setsid event
  * proc.sid filter field: the session id of the process
    generating the event
  * proc.sname filter field: the name of the current process
    session leader
  * --force-term-compat command line option: try to configure
    simple terminal
  * settings (xterm-1002) that work better with terminals like
    putty
  * Many minor bugfixes
  * builds with gcc6 (boo#985121)
- Use pkgconfig() style dependencies
- Build with lua-5.1 as builds fail with lua-5.2 and later
* Tue Apr 12 2016 mpluskal@suse.com
- Update to 0.9.0
  * Mesos and Marathon support:
  + csysdig views: Mesos Tasks, Mesos Frameworks, Marathon Apps,
    arathon Groups
  + -m sysdig/csysdig parameter to specify URLs for Mesos Master
    Marathon API
  + -pm sysdig parameter to get a Mesos-friendly event output
  + Filter fields: mesos.task.name, mesos.task.id,
    mesos.task.label, mesos.task.labels, mesos.framework.name,
    mesos.framework.id, marathon.app.name, marathon.app.id,
    marathon.app.label, marathon.app.labels, marathon.group.name,
    marathon.group.id
  * icontains filter comparison operator: case-insensitive string
    comparison
  * Support for SSL based authentication and bearer token
    authentication against the Kubernetes API server. Previously,
    SSL was just supported for CA verification. See the updated
    documentation for -K
  * New actions on csysdig views: lsof and renice
  * New network filter fields that support a CIDR notation
    (e.g. 127.0.0.1/24): fd.net, fd.cnet, fd.snet, fd.lnet, fd.rnet
* Sat Feb  6 2016 mpluskal@suse.com
- Update to 0.8.0
  * Bug fixes
    + Better terminal mouse handling for csysdig
    + Minor bugfixes
  * New and updated features
    + rkt support (when running sysdig in a container, bind
    mounting the rkt directory is necessary, e.g. -v
    /var/lib/rkt:/host/var/lib/rkt:ro for Docker)
    + chroot event
    + container.type: the container type, e.g. docker or rkt
    + Prebuild sysdig-probe for Debian kernels
* Tue Jan 26 2016 mpluskal@suse.com
- Update to 0.7.1
  * Fix sysdig-probe compilation for kernel < 3.4.0
  * Fix compilation on OSX
- Changes for 0.7.0
  * Fix sysdig-probe for kernel 4.4
  * Fix a remotely possible deadlock during ioctl calls
  * Fix Kubernetes support when data returned from the API server
    is particularly big
  * Minor bugfixes
  * Spectrogram views in csysdig: spectro_all (System call latency
    spectrogram) and spectro_file (File I/O latency spectrogram)
  * Ability to authenticate to a Kubernetes API server using a
    certificate, via -K <file_name> or --k8s-api-cert=<file_name>.
    Can also be specified via the environment variable
    SYSDIG_K8S_API_CERT
  * Ability to sort columns in csysdig views using the keyboard
  * --filter-proclist: apply the filter to the process table
  * -M: add the possibility to stop collecting after X seconds
    evt.latency.quantized: 10-base log of the delta between an
    exit event and the correspondent enter event evt.latency.human:
    delta between an exit event and the correspondent enter event,
    as a human readable string (e.g. 10.3ms)
* Sat Dec 19 2015 aspiers@suse.com
- Fix .spec file bug which was causing Frankenstein kernel modules:
  https://github.com/draios/sysdig/issues/496#issuecomment-165929462
* Fri Dec 18 2015 mpluskal@suse.com
- Exclude archs on which build fails
* Thu Dec 17 2015 aspiers@suse.com
- Fix whitespace issues in .spec and .changes files
- Remove duplicate %%{_datadir} directory from %%files
* Thu Dec 17 2015 mpluskal@suse.com
- Update to 0.6.0
  * Full support to Kubernetes, even when saving events to a trace
    file
  * semget system event
  * access system event
  * Automatically build sysdig-probe for boot2docker releases
  * Properly filter process table serialization in a trace file
    when a process filter is used
  * Some csysdig actions now ask the user for confirmation
  * various bugfixes
  * drop GH_496_fix.patch
* Sun Dec 13 2015 mpluskal@suse.com
- Update to 0.5.1
  * Fix connection to HTTPS Kubernetes API servers
  * Properly compile bundled OpenSSL
  * Fix sysdig-probe build on Linux 4.3
  * Minor bugfixes
- Changes for 0.5.0:
  * Full Kubernetes support!
  * Add a convenient USE_BUNDLED_DEPS CMake option to
    enable/disable all bundled dependencies at once.
  * New build/runtime dependencies: libb64, libcurl, openssl.
- Add GH_496_fix.patch
- Update dependencies and not use anything bundled
* Wed Nov  4 2015 rpm@fthiessen.de
- Updated to 0.4.0, notable changes:
  * Support ia32 emulation on 64bit kernels
  * HTTP chisels now support UNIX sockets (e.g. Docker API)
  * New events: mount, umount
  * Support Docker containers when running in a different cgroup
    root layout
  * csysdig view actions: press F7 or F8 while inside a csysdig
    view to see what actions are supported
* Wed Nov  4 2015 rpm@fthiessen.de
- Updated to 0.2.0, notable changes:
  * New version scheme
  * Update ncurses so it will compile on GCC 5
  * Don't use GCC 5 inside the Docker container,
    because older kernels are still not ready
  * Support CPU hotplug
  * Fix improper access to socket structure during accept()
  * Docker image now includes the RUN label to make it easier to
    run sysdig on Atomic Linux
  * New events: semop, semctl, ppoll
  * Port numbers will be automatically converted to service names
    unless -N is specified
* Wed Aug 12 2015 mpluskal@suse.com
- Use proper cmake macros
- Remove conditions around fdupes as package does not build for
  old releases anyway
- Enable parallel build
* Tue Aug 11 2015 boris@steki.net
- updated from 0.1.99 to 0.1.102
- notable changes:
  * Support for decoding setns and flock syscall
  * Parse O_CLOEXEC flag on open and related syscalls
  * Parse CLONE_NEWUSER flag on clone
  * Support truncated tracefiles
  * Now sysdig can rotate tracing file when capturing, using -C, -e, -W, -G
  * Better extraction/filtering capabilities for event
    related to multiple file descriptors, like poll
  * Precompiled kernel modules for older coreos releases
  * This release introduces csysdig, the awesome ncurses user interface for sysdig
  * Support for intercepting signals via the signaldeliver event:
    parameters are source pid, destination pid and signal type
  * Docker container ships with GCC 4.8 other than the
    latest from Debian, to increase compatibility
  * echo_fds chisel has a better formatting
  * Correctly show container output even when
    renaming containers on Docker >= 1.5
* Sun May  3 2015 joop.boonen@opensuse.org
-  Cleaned and corrected the spec file
* Wed Mar 25 2015 joop.boonen@opensuse.org
- Cleaned the spec file up
- Build version 0.1.99
* Wed May 28 2014 m4mnux@gmail.com
- Initial version
